@@ -236,7 +236,7 @@ def auto_parse(item, response):
 def __get_content_extract(response, path):
     text = response.xpath(path).extract_first()
     if text:
-        return text.strip()
+        return text.replace('\xa0', ' ').strip()
     return text
 
 
